@@ -24,7 +24,7 @@ def my_print_cb(data, buffer, date, tags, displayed, highlight, prefix, message)
                          u"message" : message,
                          u"to_me"   : message_is_to_me }
     actions = imp.generate_actions_from_irc_message(incoming_message)
-    imp.perform_actions(actions)
+    imp.perform_actions(actions, weechat.prnt)
     return weechat.WEECHAT_RC_OK
 
 def is_message_for_me(highlight):
